"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const NalogClient_1 = __importDefault(require("./NalogClient"));
const getTotalAmount_1 = __importDefault(require("./utils/getTotalAmount"));
const cross_fetch_1 = __importDefault(require("cross-fetch"));
class NalogApi extends NalogClient_1.default {
    constructor({ inn, password, phone }) {
        super({ inn, password, phone });
    }
    getUserInfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.callMethod("user");
        });
    }
    addIncome(services, date = new Date()) {
        return __awaiter(this, void 0, void 0, function* () {
            services = Array.isArray(services) ? services : [services];
            const totalAmount = (0, getTotalAmount_1.default)(services);
            const { approvedReceiptUuid, message } = yield this.callMethod("income", {
                paymentType: "CASH",
                ignoreMaxTotalIncomeRestriction: false,
                client: { contactPhone: null, displayName: null, incomeType: "FROM_INDIVIDUAL", inn: null },
                requestTime: new Date(),
                operationTime: new Date(date),
                services,
                totalAmount
            });
            if (!approvedReceiptUuid) {
                throw new Error(message || "Failed to add income");
            }
            return approvedReceiptUuid;
        });
    }
    cancelIncome(receiptUuid, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            const { incomeInfo, message } = yield this.callMethod("cancel", {
                receiptUuid,
                comment,
                partnerCode: null,
                requestTime: new Date()
            });
            if (!incomeInfo) {
                throw new Error(message || "Failed to cancel income");
            }
            return incomeInfo;
        });
    }
    getApprovedIncome(receiptUuid, format = "json") {
        return __awaiter(this, void 0, void 0, function* () {
            const inn = yield this.getInn();
            const r = yield (0, cross_fetch_1.default)(`${this.apiUrl}/receipt/${inn}/${receiptUuid}/${format}`);
            return format === "json" ? yield r.json() : yield r.blob();
        });
    }
}
exports.default = NalogApi;
//# sourceMappingURL=NalogApi.js.map